function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { graphql } from 'react-apollo';
import { Loading } from '../../../components/Loading';
import { currentUserQuery } from '../api';
import { userHasPermission } from '../utilities';

function securedPage(options) {
  return function (WrappedComponent) {
    var SecuredPage = function SecuredPage(_ref) {
      var data = _ref.data,
          restProps = _objectWithoutProperties(_ref, ['data']);

      var loading = data.loading,
          error = data.error,
          currentUser = data.currentUser;


      if (loading) {
        return React.createElement(Loading, null);
      }

      if (!loading && error) {
        return React.createElement(
          'p',
          null,
          'Request error'
        );
      }

      if (!loading && !userHasPermission(currentUser, options.permission)) {
        return React.createElement(
          'p',
          null,
          'Forbidden'
        );
      }

      return React.createElement(WrappedComponent, restProps);
    };

    SecuredPage.propTypes = {
      data: PropTypes.object.isRequired
    };

    return graphql(currentUserQuery, {
      options: { fetchPolicy: 'cache-only' }
    })(SecuredPage);
  };
}

export default securedPage;