import React from 'react';
import PropTypes from 'prop-types';
import { createBatchingNetworkInterface, ApolloClient, ApolloProvider } from 'react-apollo';
import { configureStore } from '../../../modules/store';
import { authBatchMiddleware } from '../../Auth';
import { Notifications } from '../../../components/Notifications';

var LayoutRoot = function LayoutRoot(_ref) {
  var children = _ref.children,
      graphQLUrl = _ref.graphQLUrl,
      initialState = _ref.initialState,
      middleware = _ref.middleware,
      reducers = _ref.reducers;

  var networkInterface = createBatchingNetworkInterface({ uri: graphQLUrl, batchInterval: 10 });
  var apolloClient = new ApolloClient({ networkInterface: networkInterface });
  var store = configureStore(apolloClient, reducers, initialState, middleware);

  networkInterface.use([authBatchMiddleware]);

  return React.createElement(
    ApolloProvider,
    { store: store, client: apolloClient },
    React.createElement(
      'section',
      { className: 'department' },
      children,
      React.createElement(Notifications, null)
    )
  );
};

LayoutRoot.propTypes = {
  children: PropTypes.node.isRequired,
  graphQLUrl: PropTypes.string.isRequired,
  initialState: PropTypes.object,
  middleware: PropTypes.array,
  reducers: PropTypes.object
};

export default LayoutRoot;